timerelationtools.timespan_2_intersects_timespan_1
==================================================

.. autofunction:: abjad.tools.timerelationtools.timespan_2_intersects_timespan_1.timespan_2_intersects_timespan_1
   :noindex:
